<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=cpf
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Fé zoué lo plugin',
	'aide_non_disponible' => 'Astèr i mank ankor inn bout lo koudmin an liyn pou la lang ou la swazi.',
	'auteur' => 'Lotèr :',
	'avis_acces_interdit' => 'Ou nana pwinn lapermisyon pou rant dann kwind sit-la.',
	'avis_article_modifie' => 'Tansyon pangar, @nom_auteur_modif@ la fin travayé lartik-la, néna  @date_diff@ minit pasé',
	'avis_aucun_resultat' => 'Néna pwinn rézilta.',
	'avis_chemin_invalide_1' => 'Somin ou la swazi',
	'avis_chemin_invalide_2' => 'i sanm pa marsé. Ou pé artourn paz-déryèr èk vèy bann zinformasyon ou la doné.',
	'avis_connexion_echec_1' => 'Lakostaz-la sir servèr SQL la finn loupé.', # MODIF
	'avis_connexion_echec_2' => 'Artourn paz-déryèr èk vèy byin bann zinformasyon ou la doné.',
	'avis_connexion_echec_3' => '<b>Tansyon Pangar !</b> Sir bonpé servèr i dwa <b>domann</b> léberzèr li fé zwé out permisyon pou lakostaz labaz SQL, sinonsa i pé pa giny anserv ali. Si ou lé pa kav akost labaz, véy byin si ou la domandé permisyon-la.', # MODIF
	'avis_connexion_ldap_echec_1' => 'Lakostaz-la si lo servèr LDAP, li la pa finn marsé.',
	'avis_connexion_ldap_echec_2' => 'Artourn paz-déryèr èk vèy byin bann zinformasyon ou la doné.',
	'avis_connexion_ldap_echec_3' => 'Dann ka-la,i giny pa a rien anserv lo supor LDAP pou import a bann zitilizatèr.', # MODIF
	'avis_deplacement_rubrique' => 'Pangar ! Dann rubrik-la néna @contient_breves@ brève@scb@ : si ou dékal ali, mèt inn krwa pou kofirmé.',
	'avis_erreur_connexion_mysql' => 'Astèr néna inn kanard èk lakostaz SQL',
	'avis_espace_interdit' => '<b>Ou na pwinn permisyon ariv dann lépas-tèrla </b><p>Ou la déza finn mèt inn versyon d-SPIP.', # MODIF
	'avis_lecture_noms_bases_1' => 'Program linstalasyion-la, li na pwinn finn ginyé dlir bann non bann bazdodné sak lé prézan dann sit.',
	'avis_lecture_noms_bases_2' => 'Kiswa néna okinn baz disponib, kiswa fonksyon "listé bann bazdodné" la finn dèt apiyé porézon sékirité (néna plisyèr zéberzèr sak i dégrèn ali).',
	'avis_lecture_noms_bases_3' => 'Si dernyèr idé-la lé vré, lé probab ou i pé anservir inn bazdodné sak i port out nondkod :',
	'avis_non_acces_page' => 'Ou na pwinn permisyon akost sir pazwèb-la.',
	'avis_operation_echec' => 'Lopérasyon-la la pwinn finn marsé. ',
	'avis_suppression_base' => 'TANSYON PANGAR, si ou i dégrèn bann doné-la, i pé pa bataryèr pou rékupèr azot : ou sava pèrd tout bann zinformasyon',

	// B
	'bouton_acces_ldap' => 'Azout laksé dann LDAP >>',
	'bouton_ajouter' => 'Azouté',
	'bouton_demande_publication' => 'Domann lapiblikasyon lartik-la',
	'bouton_desactive_tout' => 'Dégrenn tout zot',
	'bouton_effacer_tout' => 'Dégrèn a TOUT',
	'bouton_envoyer_message' => 'Modékri-la lé fini : anvwa ali',
	'bouton_modifier' => 'Sanz',
	'bouton_radio_afficher' => 'Fé vwar an liyn',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Amontr aou dann bann lotèr an liyn ', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Anvwa bann zanons sir ladrès-la :',
	'bouton_radio_envoi_liste_nouveautes' => 'Anvwa lalist bann nouvèlté',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Bann lotèr-la i pé pa vwar ou lé an liyn

', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Anpès anvwayé bann zanons léditoryal',
	'bouton_redirection' => 'TOURNÉVIRÉ LADRÈSWÈB',
	'bouton_relancer_installation' => 'Rosarz linstalasyon',
	'bouton_suivant' => 'Answit',
	'bouton_tenter_recuperation' => 'Eséy inn aranzman',
	'bouton_test_proxy' => 'Eséy lo proksi-la',
	'bouton_vider_cache' => 'Dévid kas lo sitwèb',

	// C
	'cache_modifiable_webmestre' => 'Lo wèbmèt lo sit, li pé sanz paramèt-la. ', # MODIF
	'calendrier_synchro' => 'Si ou ansèrv in lozisyèl pou in lajinda i mars èk <b>iCal</b> (Apple iCal, Mozilla Calendar, Ximian Evolution, KOrganizer...),ou pé mèt ali si lo ritm bann arnouvèlman laktyalité lo sit-la.',

	// D
	'date_mot_heures' => 'èr',

	// E
	'email' => 'ladrès imèl',
	'email_2' => 'ladrès imèl :',
	'entree_adresse_annuaire' => 'Ladrès karné',
	'entree_adresse_email' => 'Out ladrès imèl',
	'entree_base_donnee_1' => 'Ladrès labazdodné',
	'entree_base_donnee_2' => '(Souvandfwa ladrès-la lé paréy sak ladrès lo sitwèb, nadfwa pwatan lé inn sinp « localhost », nadfwa lé vid.)',
	'entree_biographie' => 'Arkont inn pé kisa ou lé.',
	'entree_chemin_acces' => '<b>Mèt</b> lo somin-laksé :',
	'entree_cle_pgp' => 'Out klé PGP',
	'entree_contenu_rubrique' => '(Kosa moun i va trouv dann rubrik-la, an kèk mo sèlman.)',
	'entree_identifiants_connexion' => 'Out nondkod é modpas pou akost lo sitwèb...',
	'entree_informations_connexion_ldap' => 'Mersi mèt dann komisyon-la bann zinformasyon nésésèr pou akost lo karné LDAP.


Bann zinformasyon-la, sé komandèr-sistèm ou komandèr-rézo sak i dwa donn a ou.', # MODIF
	'entree_infos_perso' => 'Kisa ou lé ?',
	'entree_interieur_rubrique' => 'Dann rubrik :',
	'entree_liens_sites' => '<b>Gatiraz</b> (égsanp : sitwèb lé konséyé, tousala...)',
	'entree_login' => 'Out nondkod',
	'entree_login_connexion_1' => 'Lo nondkod lakostaz',
	'entree_login_connexion_2' => '(nadfwa lé paréy out nondkod-laksé FTP ; nadfwa lé vid)',
	'entree_mot_passe' => 'Out modpas',
	'entree_mot_passe_1' => 'Modpas lakostaz',
	'entree_mot_passe_2' => '(Nadfwa lé paréy out modpas pou FTP ; nadfwa lé vid)',
	'entree_nom_fichier' => 'Mersi mèt lo non do fisyé @texte_compresse@ :',
	'entree_nom_pseudo' => 'Out vrénon oubyin ti-non-gaté',
	'entree_nom_pseudo_1' => '(Out vrénon oubyin ti-non-gaté)',
	'entree_nom_site' => 'Lo non out sitwèb',
	'entree_nouveau_passe' => 'Nouvo modpas',
	'entree_passe_ldap' => 'Modpas',
	'entree_port_annuaire' => 'Lo niméro d-por dlo karné ',
	'entree_signature' => 'Sinyatir',
	'entree_titre_obligatoire' => '<b>Titr</b> [Nésésèr]<br />',
	'entree_url' => 'Ladrès (URL) out sitwèb',
	'erreur_plugin_fichier_absent' => 'Okin fisyé ',
	'erreur_plugin_fichier_def_absent' => 'Nena pa okinn fisyé po définisyon',
	'erreur_plugin_nom_fonction_interdit' => 'Lonon fonksyon la lé intèdi',
	'erreur_plugin_nom_manquant' => 'Nena pa okinn non pou plugin la',
	'erreur_plugin_prefix_manquant' => 'L’espas pou donn in non pou pligin la li pa défini',
	'erreur_plugin_tag_plugin_absent' => 'Nena pa okinn &lt;plugin&gt; andan fisyé pou la definisyon',
	'erreur_plugin_version_manquant' => 'Nena pa okinn vésyon pou plugin la',

	// I
	'ical_info1' => 'Paz-la i donn aou plizièr manyèr rès an gatiraz èk lo vi lo sit-la.',
	'ical_info2' => 'Si ou i vé dot ranseyman si bann teknik anlèr, ezit pa rogardé <a href="@spipnet@">bann paz dokimantasyon pou SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'Astèr néna dé kalandryé disponib. Promyé lé in manyèr d’kart pou lo sit, sak i donn a ou tout bann zartik la finn dèt pibliyé. Dézièm-la, i donn aou tout bann zanons léditoryal èk zot dernyé modékri andann out léspas privé (out kazmodékri) : laksé dézyèm kalandryé-la, li lé rézervé. ou minm sèlman lé kav konsilt ali sanm inn sort klé privé, sak ou pé sanz kank i vé (sanz sèlman out modpas). ',
	'ical_methode_http' => 'Télésarzman',
	'ical_methode_webcal' => 'Po fé lasinkronizasyon(webcal://)', # MODIF
	'ical_texte_prive' => 'Kalandryé-la lé sèlman disponib pou ou-minm. I di aou kosa i lé laktivité éditoryal lo sitwèb (kosa ou dwa fé, kank i lé out bann randévou, kank bann zartik èk bann tite-nouvèl la finn dèt propozé...).',
	'ical_texte_public' => 'Kalandryé-la i di aou kosa i lé laktivité pibli si lo sitwèb (i rappèl tout bann zartik èk tite-nouvèl sat la finn dèt pibliyé).',
	'ical_texte_rss' => 'Ou pé sindiké bann nouvèlté lo sit-la, kiswa i lé out léktèr bann fisyé andan lo forma  XML/RSS (Rich Site Summary). Forma-la i rann a SPIP kav lir bann nouvèlté dot bann sitwèb, tout sat i ansèrv in forma lésanz konpatib y pé apareyé vèk bann zot-la.',
	'ical_titre_js' => 'Javascript (Zavaskrip)',
	'ical_titre_mailing' => 'Lètlimèl',
	'ical_titre_rss' => 'Bann fisyé pou la sindikasyon',
	'icone_activer_cookie' => 'Fé zwé lo gatomakro d rokonésans ',
	'icone_admin_plugin' => 'Jèré bann plugin',
	'icone_afficher_auteurs' => 'Armontr bann lotèr',
	'icone_afficher_visiteurs' => 'Armontr bann vizitèr',
	'icone_arret_discussion' => 'Anbar ou mèt ansanm dann kozman-la ',
	'icone_calendrier' => 'Kalandriyé',
	'icone_creer_auteur' => 'Kré inn nouvo lotèr é mèt ali  ansanm dann lartik-la',
	'icone_creer_mot_cle' => 'Kré inn nouvo molaklé è gatir ali sanm lartik-la.',
	'icone_creer_rubrique_2' => 'Kré inn nouvèl rubrik',
	'icone_modifier_article' => 'Sanz lartik-la',
	'icone_modifier_rubrique' => 'Sanz rubrik-la',
	'icone_retour' => 'Bat-aryèr',
	'icone_retour_article' => 'Bat-aryèr si lartik',
	'icone_supprimer_cookie' => 'Dégrèn gatomakro pou larokonésans',
	'icone_supprimer_rubrique' => 'Dégrèn rubrik-la',
	'icone_supprimer_signature' => 'Dégrèn sinyatir-la',
	'icone_valider_signature' => 'Konfirm sinyatir-la',
	'image_administrer_rubrique' => 'Ou néna drwa d-komandman sir rubrik-la',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 lartik',
	'info_activer_cookie' => 'I pé fé zwé inn <b>gatomakro drokonésans </b>. Kom sa ou sra kav pas fasilman dopwi lafigirwèb piblik sir lo sit privé.',
	'info_administrateur' => 'Komandèr', # MODIF
	'info_administrateur_1' => 'Komandèr', # MODIF
	'info_administrateur_2' => 'lo sitwèb(<i>anserv èk prékosyon</i>)',
	'info_administrateur_site_01' => 'Si ou lé komandèr lo sit, mersi', # MODIF
	'info_administrateur_site_02' => 'klik gatiraz-la',
	'info_administrateurs' => 'Bann komandèr', # MODIF
	'info_administrer_rubrique' => 'Ou pé zèr larubrik-la',
	'info_adresse' => 'si ladrès :',
	'info_adresse_url' => 'Ladrès (URL) lo sit piblik (figirwèb)',
	'info_aide_en_ligne' => 'Koudmin an liyn SPIP',
	'info_ajout_image' => 'Kank ou azout inndé zimaz pou mèt inn dokiman-zwinn èk inn lartik,
SPIP i pé kré otomatikman inndé vinyèt (inndé tit-limaz), aparti 
 tout bann zimaz ou la déza sarzé. Sa lé itil pou kré
inn liv-zimaz (sédir inn galri).',
	'info_ajouter_rubrique' => 'Azout inn ot rubrik pour okipé :',
	'info_annonce_nouveautes' => 'Zanons bann nouvèlté',
	'info_article' => 'Lartik',
	'info_article_2' => 'bann zartik',
	'info_article_a_paraitre' => 'Bann zartik pou pibliyé èk inn dat postéryèr lo zour son lékritir ',
	'info_articles_02' => 'bann zartik',
	'info_articles_2' => 'Bann zartik',
	'info_articles_auteur' => 'Bann zartik lotèr-la',
	'info_articles_trouves' => 'Bann zartik la finn dèt trouvé',
	'info_attente_validation' => 'Out bann zartik sak i espèr lakonfirmasyon',
	'info_aujourdhui' => 'Zordi :',
	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
	'info_auteurs' => 'Bann lotèr',
	'info_auteurs_par_tri' => 'Bann lotèr@partri@',
	'info_auteurs_trouves' => 'Bann lotèr la finn dèt trouvé',
	'info_authentification_externe' => 'Lotantifikasyon-déor pour out lidantité',
	'info_avertissement' => 'Lavi',
	'info_base_installee' => 'Lastriktir out bazdodné lé instalé.',
	'info_chapeau' => 'Sapo',
	'info_chapeau_2' => 'Sapo :',
	'info_chemin_acces_1' => 'Bann lopsyon : <b>Somin laksè dann karné</b>',
	'info_chemin_acces_2' => 'Astèr i dwa konfigir lo somin laksé pou bann zinformasyon dann karné. Linformasyon-la lé nésésèr pou lir bann profil zitilizatèr. Profil-la lé stoké dann karné.', # MODIF
	'info_chemin_acces_annuaire' => 'Bann lopsyon : <b>Somin-laksé dann karné',
	'info_choix_base' => 'Trwazièm étap :',
	'info_classement_1' => '<sup>yé</sup> si @liste@',
	'info_classement_2' => '<sup>èm</sup> si @liste@',
	'info_code_acces' => 'Oubliy pa out prop bann kod-laksé !',
	'info_config_suivi' => 'Si ladrès-la lé inn ladrès po inlistmèl, ou pé présiz anba tèrla kosa i lé ladrès out bann vizitèr i pé inskri azot. Ladrès-la i pé èt in sinp URL (lapaz pou linskrisyon si lo sit-minm), o in ladrès imèl, po un sizé pli spésifik(égsanp : <tt>@adresse_suivi@?subject=subscribe</tt>) :',
	'info_config_suivi_explication' => 'Ou pé abonn aou po gigny lo listmèl  lo sit-. Ou sar gigny in limèl pou tout bann zanons èk bann tite-nouvèl sat ni propoz po lapiblikasyon  si lo sit.',
	'info_confirmer_passe' => 'Konfirm out nouvo modpass-la :',
	'info_connexion_base' => 'Dezièm étap : <b>Esèy lakostaz-labaz</b>',
	'info_connexion_ldap_ok' => 'Lakostaz LDAP la finn marsé.</b><p>Ou pé bat-karé si létap answit.', # MODIF
	'info_connexion_mysql' => 'Promyèr étap : <b>Out lakostaz SQL</b>',
	'info_connexion_ok' => 'Lakostaz la finn marsé.',
	'info_contact' => 'Kontak',
	'info_contenu_articles' => 'Kosa bann zartik i kontyin ',
	'info_creation_paragraphe' => '(Pou kré bann paragraf, lès sinpman trwakat liyn vid.)', # MODIF
	'info_creation_rubrique' => 'Avand ékrir bann zartik minm ,<br /> i dwa kré inn rubrik o mwin.<br />',
	'info_creation_tables' => 'Katryèm étap : <b> kréasyon inndé tab labaz</b>',
	'info_creer_base' => '<b>Kré</b> inn nouvèl bazdodné :',
	'info_dans_rubrique' => 'Dann rubrik-la :',
	'info_date_publication_anterieure' => 'Avans ladat lapiblikasyon :',
	'info_date_referencement' => 'DAT LO RÉFÉRANSMAN SITWÈB-LA :',
	'info_derniere_etape' => 'Dernyèr étap : <B > Ala ! Tousala lé fini !',
	'info_descriptif' => 'Sak i kontyin :',
	'info_discussion_cours' => 'Bann kozman ou lé apré kozé ',
	'info_ecrire_article' => 'Ou i dwa dabor kré inn promyé rubrik avand ékri out bann zartik.',
	'info_email_envoi' => 'Ladrès po lanvwa inn lilèl(lépa obligatwar)',
	'info_email_envoi_txt' => 'Mèrsi indiké tèrla out ladrès pou anvwa bann zimèl (sinonsa ladrès déstinatèr li sra ansèrvi osi kom ladrès lanvwa) :',
	'info_email_webmestre' => 'Ladrès imèl lo wèbmèt (lé pa obligatwar)', # MODIF
	'info_envoi_email_automatique' => 'Anvwa inn limèl otomatikman',
	'info_envoyer_maintenant' => 'Anvwa astèr',
	'info_etape_suivante' => 'Pas létap answit',
	'info_etape_suivante_1' => 'I pé pas létap answit.',
	'info_etape_suivante_2' => 'I pé pas létap answit.',
	'info_exportation_base' => 'Lésportasyon labaz aprosan  @archive@',
	'info_facilite_suivi_activite' => 'Pou swiv fasilman laktivité léditoryal sir lo sit, SPIP i pé anvwa inn zanons dann fil-imèl pou tout bann zitilizatèr anrozistré. Zanons komsa i kadr tout bann dommand pou lapiblikasyon oubyinsa bann konfirmasyon do dernyé bann zartik.', # MODIF
	'info_fichiers_authent' => 'Bann fisyé pou lotantifikasyon « .htpasswd »',
	'info_forums_abo_invites' => 'Out sit néna bann forom si labonman ; Ifo bann vizitèr li inskri azot si lo sit piblik.', # MODIF
	'info_gauche_admin_tech' => '<b>Pazwèb-la, lé sèlman ouvèr pour inndé responsab lo sit.</b><p> Li donn laksé sir bann fonksyon pou lantrotyen tèknik. Nana désertin sak i domann aou fé zwé inn prosésus spésial pou lotantifikasyon. Dann ka-la inn laksé FTP lé
néséser pou sanz inn sizé sir lo sit.', # MODIF
	'info_gauche_auteurs' => 'Ou va trouv tèrla tout bann lotèr lo sitwèb.
 Bann drwa pou bann dalon lé kadré èk la koulèr likonn azot (komandèr= vèr ;lotèr = zonn).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Bann lotèr-déor, sak nana pwinn laksé sir lo sitwèb, lé présizé èk inn likonn blé ; bann lotèr dégréné lé kadré èk inn korbéy.', # MODIF
	'info_gauche_messagerie' => 'Kazmodékri-la i permé azot mèt ansanm pou lanvwa inndé modékri antrozot, gard out prop bann gardandèt, ou byin sa ankor : afis tout bann zanons sir pazlakèy dann zéspas privé (si ou lé komandèr).', # MODIF
	'info_gauche_statistiques_referers' => 'Pazwèb-la i prézant lo fil <i>bann référèr</i>, ou poutoudir lo fil bann sit sak i gatir out prop sitwèb. Rannkont-la lé selman valab po yèr é zordi : fil-la i ropat zéro tout bann 24H.',
	'info_gauche_visiteurs_enregistres' => 'Ou va trouv tèrla bann vizitèr anroziztré sir figirwèb piblik (bann forom sir labonman).',
	'info_generation_miniatures_images' => 'La kréasyon bann miniatyr pou bann zimaz',
	'info_hebergeur_desactiver_envoi_email' => 'Nana désertin lébèrzèr sak i défalk lanvwa otomatik do bann limèl, dopwi
zot bann servèr. Dann ka-la, bann  fonksyonalité
SPIP anba-la, i sava pa marsé.',
	'info_hier' => 'Yèr :',
	'info_identification_publique' => 'Out lidantité piblik...',
	'info_image_process' => 'Mersi swazi lo méyèr manyir pou fabrik out bann vinyèt sam apiyé si limaz i korespon.',
	'info_image_process2' => '<b>Pangar</b> <i>Si néna okinn zimaz sat i pé vwar an liny, i pé dir lo sèrvèr li ébèrz out sitwèb lé pa kofigiré po akèy bann zouti-la. Ifo zot i koz èk lo résponsab po domann ali tout bann zekstansyon « GD » ou « Imagick ».</i>', # MODIF
	'info_images_auto' => 'Ban zimaz-la lé kalkilé otomatikman',
	'info_informations_personnelles' => 'Sinkyèm étap : <b>Bann zinformasyon personèl</b>',
	'info_inscription_automatique' => 'Pou inskri otomatikman tout bann nouvo lotèr', # MODIF
	'info_jeu_caractere' => 'Lansamn bann karaktèr lo sit',
	'info_jours' => 'bann zor',
	'info_laisser_champs_vides' => 'lès a bann karo-la vid)',
	'info_langues' => 'Bann lang lo sitwèb',
	'info_ldap_ok' => 'Lotantifikasyon LDAP li lé  instalé.',
	'info_lien_hypertexte' => 'gatiraz wèb :',
	'info_liste_redacteurs_connectes' => 'Fil bann lotèr an liyn', # MODIF
	'info_login_existant' => 'Nondkod-la li lé déza anservi.',
	'info_login_trop_court' => 'Nondkod-la lé takini : ékart ali.',
	'info_maximum' => 'Pli gran siksé :',
	'info_meme_rubrique' => 'Andann mèm ribrik-la',
	'info_message_en_redaction' => 'Out bann modékri lé apré lékritir ',
	'info_message_technique' => 'Lavi tèknik :',
	'info_messagerie_interne' => 'Kazmodékri',
	'info_mise_a_niveau_base' => 'arnivèlman out labaz SQL',
	'info_mise_a_niveau_base_2' => '{{Tansyon pangar !}} Ou nana finn instalé inn verszyon
vyé fisyé SPIP. Versyon-la lé pli zansyinn sak lété 
avan sir lo sit : out bazdodné i sava dégréné
 oubyinsa out siwèb minm i sava pli marsé<br />{{Lé néséser arinstal tout bann 
fisyé SPIP.}}',
	'info_modifier_rubrique' => 'Sanz la rubrik :',
	'info_modifier_titre' => 'Sanz : @titre@',
	'info_mon_site_spip' => 'Sit SPIP amwin',
	'info_moyenne' => 'Mwayinn :',
	'info_multi_cet_article' => 'Patwa lartik-la :',
	'info_multi_langues_choisies' => 'Swazi anba-tèrla bann lang ou vé pèrmèt out bann zitilizatèr i ansèrv sir out sitwèb.
  Zot i pé pa dégrèn bann lang sak lé déza prézan sir out sitwèb (ni afis azot dabor).
 ', # MODIF
	'info_multi_secteurs' => '...sèlman pou bann ribrik ou la plas dann rasine ?',
	'info_nom' => 'Non',
	'info_nom_destinataire' => 'Non lo korespondan',
	'info_nom_site' => 'Lo non out sitwèb ',
	'info_nombre_articles' => '@nb_articles@ bann zartik,',
	'info_nombre_rubriques' => '@nb_rubriques@ bann rubrik,',
	'info_nombre_sites' => '@nb_sites@ bann sitwèb,',
	'info_non_deplacer' => 'Mèrsi pa dékalé...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP i pé avwa souvan inn zanons bann dernyèr nouvèlté si lo sitwèb (bann zartik èk tit-nouvèl
la finn dèt publyé).',
	'info_non_envoi_liste_nouveautes' => 'Ampès anvwa lo fil bann nouvèlté',
	'info_non_modifiable' => 'ou pé pa sanz ali',
	'info_non_suppression_mot_cle' => 'Mi vé pa dégrèn molaklé-la.',
	'info_notes' => 'Bann komantèr',
	'info_nouvel_article' => 'Nouvo lartik',
	'info_nouvelle_traduction' => 'Nouvèl tradiksyon :',
	'info_numero_article' => 'LARTIK NIMÉRO :',
	'info_obligatoire_02' => '[Obligatwar]', # MODIF
	'info_option_accepter_visiteurs' => 'Asèpt bann vizitèr i inskri azot si lo sit piblik', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Arfiz bann vizitèr i inskri azot', # MODIF
	'info_options_avancees' => 'BANN ZOPSYON AVANSÉ',
	'info_ou' => 'ou...',
	'info_page_interdite' => 'Pazwèb intèrdi',
	'info_par_nombre_article' => '(pou lo nonb bann zartik)',
	'info_passe_trop_court' => 'Out modpas lé tro takini.',
	'info_passes_identiques' => 'Bann dé modpass-la lé pa parèy.',
	'info_plus_cinq_car' => 'pli dé 5 karaktèr-limprimri',
	'info_plus_cinq_car_2' => '(Pli dé 5 karaktèr-limprimri)',
	'info_plus_trois_car' => '(Pli dé 3 karaktèr-limprimri)',
	'info_popularite' => 'Koman lé populèr : @popularite@ ; bann vizit : @visites@',
	'info_post_scriptum' => 'Koz-Déryèr',
	'info_post_scriptum_2' => 'Koz-déryèr :',
	'info_pour' => 'pou',
	'info_preview_texte' => 'Lé posib vwar lo sit avan komsi tout bann zartik èk bann tit-nouvèl (sat néna omwin lo statu « pou pibliyé ») zot sré astèr an liny. Ou pé swazi si lé sèlman po komandèr, po rédaktèr ou si lé pa posib ni po lin ni po lot. ', # MODIF
	'info_procedez_par_etape' => 'azi étap sanm étap',
	'info_procedure_maj_version' => 'Lé nésésèr fé zwé arnouvèlman la bazdodné pou giny roul ron la nouvèl
versyon SPIP.',
	'info_ps' => 'K.D',
	'info_publier' => 'pibliyé',
	'info_publies' => 'Out bann zartik an liyn',
	'info_question_accepter_visiteurs' => 'Si out bann lékèlet i permé out bann vizitèr inskri azot si lo sitwèb,     anon fé zwé lopsyon anba-terla :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Indik si ou laksèp linskrisyon bann nouvo lotèr dopwi lo sit piblik ? Si
 ou vé, bann lotèr i poura inskri azot èk lo formulèr otomatik. Zot i poura akosté
sir figirwèb privé é propoz zot prop zartik minm.
<blockquote><i>Dan moman linskrisyon, bann zitilizatèr i giny inn limèl otomatikman. Limèl-la i donn azot bann kod lakostaz sir figirwèb privé. Nana désertin zéberzèr
sak i dégrèn lanvwa bann limèl sir zot bann servèr : dann kala, linskrisyon otomatik li lé pa posib', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Rasin lo sitwèb',
	'info_recharger_page' => 'Mersi rosarz lapazwèb-la disi inn ti moman.',
	'info_recherche_auteur_zero' => 'Néna pa okinn rézilta pou "@cherche_auteur@".',
	'info_recommencer' => 'Mersi arcomans inn ot fwa.',
	'info_redacteur_1' => 'Lotèr',
	'info_redacteur_2' => 'sak i pé akost léspas privé (<i>konséyé</i>)',
	'info_redacteurs' => 'Bann lotèr',
	'info_redaction_en_cours' => 'LÉ APRÉ LÉKRITRIR',
	'info_redirection' => 'Tourné-viré (artourn sir inn somin wèb)',
	'info_refuses' => 'Out bann zartik lé afronté',
	'info_reglage_ldap' => 'Bann lopsyon : <b>Réglaz linportasyon LDAP</b>',
	'info_renvoi_article' => '<b>Tourné-viré.</b> Lartik-la i batavan sir pazwèb-la :',
	'info_reserve_admin' => 'Bann komandèr sélman i pé sanz ladrès-la.', # MODIF
	'info_restreindre_rubrique' => 'Mèt inn limit pou lazéstyon la rubrik-la :',
	'info_resultat_recherche' => 'Bann rézilta rodaz :',
	'info_rubriques' => 'Bann rubrik',
	'info_rubriques_02' => 'bann rubrik',
	'info_rubriques_trouvees' => 'Bann rubrik la finn dèt trouvé',
	'info_sans_titre' => 'Néna pwinn titr',
	'info_selection_chemin_acces' => '<b>Swazi</b> tèrla lo somin-laksé dann karné :',
	'info_signatures' => 'bann sinyatir',
	'info_site' => 'Sitwèb',
	'info_site_2' => 'sitwèb :',
	'info_site_min' => 'sitwèb',
	'info_site_reference_2' => 'Sitwèb référansé',
	'info_site_web' => 'SITWÈB :', # MODIF
	'info_sites' => 'bann sitwèb',
	'info_sites_lies_mot' => 'Bann sit référansé sak lé gatiré èk molalklé-la',
	'info_sites_proxy' => 'Anserv inn proksi',
	'info_sites_trouves' => 'Bann sitwèb trouvé',
	'info_sous_titre' => 'Soutitr :',
	'info_statut_administrateur' => 'Komandèr', # MODIF
	'info_statut_auteur' => 'Lo statu lotèr-la :', # MODIF
	'info_statut_auteur_a_confirmer' => 'Ou i dwa konfime out linkrisyon ',
	'info_statut_auteur_autre' => 'In ot stati :',
	'info_statut_redacteur' => 'Lotèr',
	'info_statut_utilisateurs_1' => 'Lo statu sanswa bann zitilizatèr déor', # MODIF
	'info_statut_utilisateurs_2' => 'Swazi lo ran ou vé donn do moun prézan dann karné LDAP, kank moun-la i konèk inn promyèr fwa. Ou sra kav answuit sanz valèr ou la donn azot (o ka sanm lo ka).', # MODIF
	'info_suivi_activite' => 'Swivi laktivité léditoryal',
	'info_surtitre' => 'Sirtitr :',
	'info_syndication_integrale_1' => 'Out si i propoz bann fisyé pou la sindikasyon (ann gadé « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Eske ou i vé donn tout ban lartik byen komplé, ou sèlman in ti rézimé ek détrwa sentenn karactèr ?',
	'info_taille_maximale_vignette' => 'La pli grann tay lo sistèm i pé kré pou bann vinyèt :',
	'info_terminer_installation' => 'Ou pé termin astèr lamanyir instalé SPIP an mars normal.',
	'info_texte' => 'Tèks',
	'info_texte_explicatif' => 'Esplik inn pé ',
	'info_texte_long' => '(tèks-la lé lon : akoz li aparé astèr an plizyèr karo, sak i sava kolé dinn bou aprè lakonfirmasyon.)',
	'info_texte_message' => 'Lo tèks out modékri :', # MODIF
	'info_texte_message_02' => 'Lo tèks lo modékri',
	'info_titre' => 'Titr :',
	'info_total' => 'Boudikont :',
	'info_tous_articles_en_redaction' => 'Tout bann zartik lé apré lékritir',
	'info_tous_articles_presents' => 'Tout bann zartik pibliyé dann rubrik-la',
	'info_tous_les' => 'tout bann :',
	'info_tout_site' => 'Lo sit antyé',
	'info_tout_site2' => 'Lartik lé pa tradwi andan lo patwa-la.',
	'info_tout_site3' => 'Lartik-la, li lé tradwi andan lo patwa-la, somansa ni la port bann sanzman si lartik lorizin. Larnouvèlman la tradiksyon lé nésésèr.',
	'info_tout_site4' => 'Lartik lé tradwi andan lo patwa-la. Lo tradiksyon lé bon zordi. ',
	'info_tout_site5' => 'Lartik lorizin.',
	'info_tout_site6' => '<b>Tansyon pangar :</b> bann zartik lorizin sèlman lé afisé.
Bann tradiksyon lé prézanté an gatiraz,
sanm in koulèr i présiz son léta :',
	'info_travail_colaboratif' => 'Mèt ansamn travay si bann zartik',
	'info_un_article' => 'inn lartik,',
	'info_un_site' => 'inn sit,',
	'info_une_rubrique' => 'inn rubrik,',
	'info_une_rubrique_02' => '1 rubrik',
	'info_url' => 'URL :',
	'info_urlref' => 'Gatir wèb :',
	'info_utilisation_spip' => 'Astèr ou pé anserv lo sistèm lapiblikasyon SPIP...',
	'info_visites_par_mois' => 'Afis pou lo mwa :',
	'info_visiteur_1' => 'Vizitèr',
	'info_visiteur_2' => 'lo figirwèb',
	'info_visiteurs' => 'Bann vizitèr',
	'info_visiteurs_02' => 'Bann vizitèr sir figirwèb',
	'install_echec_annonce' => 'Instalasyon-la li pè sirman dègrn ali ou sar don ou in sit sat lé pa kav roulé...',
	'install_extension_mbstring' => 'SPIP  li roul pa èk :',
	'install_extension_php_obligatoire' => 'SPIP li domann léstansyon php :',
	'install_select_langue' => 'Swazi inn kozé e klik sir lo bouton « swivan » pou fé zwé lamanyir linstalasyon.',
	'intem_redacteur' => 'lotèr',
	'item_accepter_inscriptions' => 'Asèpt bann zinskrisyon',
	'item_activer_messages_avertissement' => 'Fé zwé bann modékri pou lavizman',
	'item_administrateur_2' => 'komandèr', # MODIF
	'item_afficher_calendrier' => 'Afis dann kalandryé',
	'item_autoriser_syndication_integrale' => 'Pou don a zot tout lartik byen komplé andann bann fisyé pou la sindikasyon',
	'item_choix_administrateurs' => 'bann komandèr', # MODIF
	'item_choix_generation_miniature' => 'Pou kré otomatikman bann zimaz-minyatir (bann vinyèt).',
	'item_choix_non_generation_miniature' => 'Pou anpès kré otomatikman bann zimaz-minyatir (bann vinyèt).',
	'item_choix_redacteurs' => 'bann lotèr',
	'item_choix_visiteurs' => 'bann vizitèr sir figirwèb',
	'item_creer_fichiers_authent' => 'Pou kré bann fisyé .htpasswd',
	'item_login' => 'Nondkod',
	'item_mots_cles_association_articles' => 'èk bann zartik',
	'item_mots_cles_association_rubriques' => 'èk bann rubrik',
	'item_mots_cles_association_sites' => 'èk bann sit référansé ou sindiké.',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Anpès asèpt bann zinskrisyon',
	'item_non_activer_messages_avertissement' => 'Anpès anvwa bann modékri pou lavizman',
	'item_non_afficher_calendrier' => 'Anpès afis lo kalandryé',
	'item_non_autoriser_syndication_integrale' => 'Pour donn azot selman in rézimé',
	'item_non_creer_fichiers_authent' => 'Anpès kré bann fisyé-la',
	'item_non_publier_articles' => 'Bann zartik lé pa an liyn avan ladat sak lé di.',
	'item_nouvel_auteur' => 'Nouvo lotèr',
	'item_nouvelle_rubrique' => 'Nouvèl rubrik',
	'item_oui' => 'Wi',
	'item_publier_articles' => 'Mèt an liyn tout bann zartik san gèt ladat lapiblikasyon.',
	'item_reponse_article' => 'Répons lartik',
	'item_visiteur' => 'vizitèr',

	// J
	'jour_non_connu_nc' => 'p.k. (pa konu)',

	// L
	'lien_ajouter_auteur' => 'Azout lotèr-la',
	'lien_email' => 'limèl',
	'lien_nom_site' => 'LO NON LO SITWÈB :',
	'lien_retirer_auteur' => 'Artir lotèr-la',
	'lien_site' => 'sitwèb',
	'lien_tout_deplier' => 'Dépliy a tout',
	'lien_tout_replier' => 'Arpliy a tout ',
	'lien_trier_nom' => 'Prézant swivan lo non',
	'lien_trier_nombre_articles' => 'Prézant swivan lo nonb do bann zartik',
	'lien_trier_statut' => 'Prézant swivan lo statu',
	'lien_voir_en_ligne' => 'GÈT AN LIYN :',
	'logo_article' => 'LOGO LARTIK-LA', # MODIF
	'logo_auteur' => 'LOGO LOTÈR-LA', # MODIF
	'logo_rubrique' => 'LOGO RUBRIK-LA', # MODIF
	'logo_site' => 'LOGO SITWÈB-LA', # MODIF
	'logo_standard_rubrique' => 'LOGO POU TOUT BANN RUBRIK', # MODIF
	'logo_survol' => 'LOGO POU LOFÉ ', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Lo swa out bazdodné',
	'module_fichier_langue' => 'Fisyé lang',
	'module_raccourci' => 'Rédiyon',
	'module_texte_affiche' => 'Tèks afisé',
	'module_texte_explicatif' => 'Ou pé mèt bann rédiyon-la anadan out bann skélèt pou sit piblik. Banna i sava èt dirékman tradwui  andan diférant lang si néna byin in fisyé lang pou zot. ',
	'module_texte_traduction' => 'Lo fisyé lang  « @module@ » , zot i va trouv ali po :',
	'mois_non_connu' => 'lé pa konu',

	// O
	'onglet_repartition_actuelle' => 'astèr',

	// P
	'plugin_etat_developpement' => 'lé apré dévlopman',
	'plugin_etat_experimental' => 'lé  selman espérimental',
	'plugin_etat_stable' => 'Lé korek',
	'plugin_etat_test' => 'lé pou testé',
	'plugins_liste' => 'La lis bann plugin',

	// R
	'repertoire_plugins' => 'Répertwar :',
	'required' => '[Obligatwar]', # MODIF

	// S
	'statut_admin_restreint' => '(komandèr ti-drwa)', # MODIF

	// T
	'taille_cache_image' => 'Ban zimaz sak SPIP i pé kalkilé otomatikman (tite-zimaz dann dokiman, bann non i prézant grafikman, bann fonkson matématik dan forma TeX...)  zot i prann andan répertwar @dir@ in léspas total sat i ariv @taille@.',
	'taille_cache_octets' => 'Lo ty lo CACHE li lé astèr de @octets@.', # MODIF
	'taille_cache_vide' => 'Lo kas lé vid.',
	'taille_repertoire_cache' => 'Tay lo répertwar kas',
	'text_article_propose_publication' => 'Lartik-la lé propozé pou lapiblikasyon. Ézit pa donn out manyèr vwar dann forom lartik-la (anba lapaz).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Néna désertin servèr LDAP i afront tout bann laksé anonim. Dan ka-la, lé néséser indik inn promyé lidentifian pou laksé. Aprésa sèlman, ou i sra kav rod bann zinformasyon dan karné. Souvandfwa pwatan, ou poura lès bann karo-la vid. ',
	'texte_admin_effacer_01' => 'Komand-la i dégrèn <i>tout</i> lo kontnu la bazdodné,
<i>tout</i> minm bann laksè lotèr èk komandèr. Si ou i anserv ali, i sra nésésèr fé zwé inn nouvèl 
linstalasyon do SPIP pou kré inn nouvèl labaz èk inn promyé laksé komandèr.', # MODIF
	'texte_adresse_annuaire_1' => '(Si out karné lé instalé sir lamasin paréy minm sitwèb-la, néna grannsans i sra pour èt « localhost ».)',
	'texte_ajout_auteur' => 'Lotèr answit la fin dèt azouté pou lartik-la :',
	'texte_annuaire_ldap_1' => 'Si ou nana laksé sir inn karné(LDAP), i pé inport otomatikman bann zitilizatèr pou mèt tout zot ansanm sir out sit SPIP.', # MODIF
	'texte_article_statut' => 'Lartik-la lé :',
	'texte_article_virtuel' => 'Lartik virtyèl',
	'texte_article_virtuel_reference' => '<b>Lartik virtyel :</b> lé référansé dann out sit SPIP, somansa li lé artourné sir inn ot  URL(tourné-viré). Pou dégrèn lartournaz, éfas anlèr son ladrès URL.',
	'texte_aucun_resultat_auteur' => 'Nana pwinn rézilta pou "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Sit-la i pé armont toultan tout bann lotèr an liyn. Sa lé itil pour mèt ansanm bann modékri, dann tan minm moun lé sir lo sit (mé kank lakazmodékri lé dégréné anlèr, list-la lé pa visib). Ou pé swazi kas aou dann la list-la (bann zitilizatèr i pé pa vwar aou somansa ou pé vwar azot).', # MODIF
	'texte_auteurs' => 'BANN LOTÈR',
	'texte_choix_base_1' => 'Swazi out labaz :',
	'texte_choix_base_2' => 'Servèr SQL li kontyin  plizyèr bann bazdodné.',
	'texte_choix_base_3' => '<b>Swazi</b> anba terlà sak out lébérzèr la donn aou :',
	'texte_compte_element' => '@count@ zéléman',
	'texte_compte_elements' => '@count@ bann zéléman',
	'texte_connexion_mysql' => 'Gèt bann zinformasyon out léberzèr la don aou : si li néna SQL, ou dwa trouv bann kod pou lakostaz sir lo servèr SQL.', # MODIF
	'texte_contenu_article' => '(sak i va trouv dann lartik-la.)',
	'texte_contenu_articles' => 'Sélon lamakèt ou la swazi pou lo sit, i pé désid sak désèrtin zéléman
dann bann zartik lé pa itilizé.
Anserv lalist anba-la pou kadr byin sak lé disponib.',
	'texte_crash_base' => 'Si out bazdodné la finn 
 dégréné, éséy aranz ali otomatikman.',
	'texte_creer_rubrique' => 'Lé nésésèr ou kré innn rubrik avand ou<br /> pé ékri inn lartik. ',
	'texte_date_creation_article' => ' LADAT LAKRÉASYON LARTIK :',
	'texte_date_publication_anterieure' => 'Dat li té pibliyé avan :',
	'texte_date_publication_anterieure_nonaffichee' => 'Afis pa okinn dat pou in rédaksyon avan.',
	'texte_date_publication_article' => 'LADAT LAPIBLIKASYON AN LIYN :',
	'texte_descriptif_rapide' => 'Dékri vitman kosa i lé',
	'texte_effacer_base' => 'Dégrèn bazdodné SPIP',
	'texte_en_cours_validation' => 'Bann zartik èk bann rubrik anba-la, lé prézanté pou lapiblikasyon. Ézit pas donn ani out manyirdvwar dann bann forom i bord azot.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Pou rannd pli ris lamanyir out sit lé mi an paz, i pé anserv « bann rédiyon linprimri ».',
	'texte_fichier_authent' => '<b>Présiz byin si out sistèm SPIP li dwa kré bann fisyé spésifik <tt>.htpasswd</tt>
é <tt>.htpasswd-admin</tt> dann répertwar @dossier@ ?</b><p>
Fisyé-la, li pé èd aou pou limit laksé désertinn lotèr ou minm bann komandèr sir sèrtin kwinn out sit
(pa égsanp : zot i sra pa kav lir lo program-déor pou sifklé bann vizit).<p>
Si fisyé-la, li sèr pa ryen sir out sitwèb, lès la valèr otomatik pou lopsyon-la (dann ka-la, lo fisyé, li sra pa kréé).', # MODIF
	'texte_informations_personnelles_1' => 'Astèr lo sistèm i sra pou kré aou inn laksé personalizé si lo sitwèb.',
	'texte_informations_personnelles_2' => '(Gèt byin tousa : si néna inn nouvèl linstalasyon é si laksé i mars touzour, i pé ', # MODIF
	'texte_introductif_article' => '(Tèks pour anbèk lartik.)',
	'texte_jeu_caractere' => 'Ni konsey a ou anserv, pou out sit, lalfabé inivérsel (<tt>utf-8</tt>) : li permé afisé in teks ek tout bann lang, sank ou gigny okinn larlik ek la konpatinilité d ban navigatèr modern.',
	'texte_jeu_caractere_3' => 'Ou sit la i anserv komela lo jéd karactèr swivan :',
	'texte_jeu_caractere_4' => 'Si li korespon pa ek la réalité out ban doné (aprè ou la restora out bazdodne pa examp), ou si <em>ou la zust finn komansé  out sit</em> sat ou vé vwar ek in ot jéd bann karactèr, mersi ou mèt lo non terla :',
	'texte_login_ldap_1' => '(Lès vid pou inn laksé san lidentifikasyon ou rant in somin komplé, pa égsanp « <tt>uid=hoareau, ou=zitilizatèr, dc=domèn-amwin, dc=com</tt> ».)',
	'texte_login_precaution' => 'Tansyon pangar ! Sa lé lo non sanm ou lé konékté.
Ansèrv formulèr-la èk prékosyon...',
	'texte_mise_a_niveau_base_1' => 'Ou vyin zist d-fini larnouvèlman bann fisyé SPIP.
Ifo astèr armètanivo labazdodné.',
	'texte_modifier_article' => 'Sanz lartik :',
	'texte_multilinguisme' => 'Si ou vé zèr out bann zartik dann plizyèr lang, èk inn sistèm navigasyon konplèks, ou pé azout inn ménidswa lalang lartik ou laribrik.', # MODIF
	'texte_multilinguisme_trad' => 'Ou pé osi azout inn sistèm lazéstyon bann gatir ant tout bann tradiksyon inn minm lartik.', # MODIF
	'texte_non_compresse' => '<i>Lé pa konpèrsé</i> (akoz out servèr i pé pa fé zwé lafonksyon-la)',
	'texte_nouvelle_version_spip_1' => 'Ou la finn instal inn nouvèl versyon do SPIP.',
	'texte_nouvelle_version_spip_2' => 'Ek lo nouvèl versyon-la lé nésésèr fé zwé inn pli konplé arnouvèlman, sak dabitid. Si ou lé lo wèbmèt lo sit, mersi éfas lo fisyé @connect@. Arpran answit linstalasyon pour arnouvèl out bann paramèt pou lakostaz-labazdodné.<p> (Véy byin. : si ou la oubliyé out bann paramèt pou lakostaz, gèt inn pé lo fisyé @connect@ avann dégrèn ali...)', # MODIF
	'texte_operation_echec' => 'Bataryèr si lapazwèb davan pou  swazi ou kré inn ot labaz. Vèy byin osi tout bann zinformasyon out lébèrzèr la donn aou.',
	'texte_plus_trois_car' => 'plid 3 karaktèr-linprimri',
	'texte_plusieurs_articles' => 'Nana plisyèr lotèr trouvé pou "@cherche_auteur@" :',
	'texte_port_annuaire' => '(Valèr-la, indiké otomatikamn, li roul-ron byin normalman.)',
	'texte_presente_plugin' => 'Paj la i donn aou la lis bann plugin ou sar trouvé sir lo sit. Ou i pé fé zwé tout bann plugin ou na bezwin, ek in simp crwa dann ti caro korespondan.',
	'texte_proposer_publication' => 'Kank out lartik lé terminé, ou pé propoz ali pou lapiblikasyon.',
	'texte_proxy' => 'Dann désertin ka, lé nésésèr anserv inn <i>proksi HTTP</i> (si ou néna inn intranèt o inn rézo sak lé protézé...),
pour ariv sir tout bann sit zot la sindiké.
Dann ka-la mèt isi son ladrès, dann form présizé la 
<tt><html>http://proxy:8080</html></tt>. Sinonsa,
lés sinpman kaz-la vid.',
	'texte_publication_articles_post_dates' => 'Kosa SPIP i dwa fèr èk bann zartik sak ladat lapiblikasyon i sra pou dann fitir ?',
	'texte_rappel_selection_champs' => '[Oubli pa swazi korèkman lo karo-la.]',
	'texte_recalcul_page' => 'Si ou vé
arkalkil inn sèl paz, ni konsèy aou pas dann léspas piblik èk anserv lo bouton « arkalkil ».',
	'texte_recuperer_base' => 'Aranz la bazdodné',
	'texte_reference_mais_redirige' => 'lartik lé référansé dann out sit SPIP, mé li lé tourné-viré sir inn ot ladrès URL.',
	'texte_requetes_echouent' => 'Kank néna désertinn rokèt SQL i mars zamé
 sank ou vwa pwin okinn rézon pou sa, lé posib lafot sa lé labazdodné li-minm.</b><p>
SQL néna inn kalité pou aranz tout son bann tab 
kank zot lé abimé sanm inn aksidan. Ou pé eséy isi inn aranzman ; dan ka li mars pa,  konsèrv inn kopi lafisaz, akoz néna petèt bann zindikasyon kosa i mars pa...<p>
Si lo larlik-la i rest touzour, ifo koz do sa èk out léberzèr.<p>', # MODIF
	'texte_selection_langue_principale' => 'Ou pé swazi anba-tèrla lo« kozé prinsipal » pou out sitwèb. Swa-la, li obliz pa aou ékri out bann zartik dann lang swazi sa-minm- rezman ankor ! Li permé sirtou kadré byin :
<ul><li> lo forma otomatik pou tout bann dat sak lé afisé sir lintèrfas out sit piblik ;</li>
<li> bann karaktèr-limprimri sak SPIP i dwa anserv pou afisé bann tèks ;</li>
<li> la lang ifo ansèrv pour tout bann formulèr ;</li>
<li> la lang léspas privé.</li></ul>',
	'texte_sous_titre' => 'Soutitr',
	'texte_statistiques_visites' => '(bann bar koulèr-fénwar :  dimans / liyn koulèr-fénwar : lo sanzman lamwayinn)',
	'texte_statut_attente_validation' => 'i espèr lakonfirmasyon',
	'texte_statut_publies' => 'pibliyé an liyn',
	'texte_statut_refuses' => 'arfizé',
	'texte_suppression_fichiers' => 'Anserv lakomand-la pou dégrèn tout bann fisyé sir lo kas SPIP. Sa lé itil, pa égsanp, pou fors larkalkil do tout bann pazwèb si lo sit, kank ou la fé bann sanzman inportan dann grafism ou dann lastriktir lo sit.',
	'texte_sur_titre' => 'Sirtitr',
	'texte_table_ok' => ' : tab-la lé OK.',
	'texte_tentative_recuperation' => 'Esèy inn aranzman',
	'texte_tenter_reparation' => 'Esèy inn aranzman dla bazdodné',
	'texte_test_proxy' => 'Pou inn test lo proksi, mèt isi ladrès inn sitwèb sak ou vé testé.',
	'texte_titre_02' => 'Titr :',
	'texte_titre_obligatoire' => '<b>Titr</b> [Obligatwar]',
	'texte_travail_article' => '@nom_auteur_modif@ la finn travay sir lartik-la néna @date_diff@ minit',
	'texte_travail_collaboratif' => 'Si néna souvandfwa plisyèr lotèr pou mèt ansanm  inn travay sir lo minm lartik, lo sistèm i pé afis inn zanons spésial. Zanons-la, i pé montr azot bann zartik sak la finn dèt « ouver » inn ti pé avan. Lé pratik pou anpès bann sanzman similtané.
Mé vèy byin, lopsyon-la, li lé pa aktivé otomatikman pou anpès lafisaz inn lavizman abizif.', # MODIF
	'texte_vide' => 'vid',
	'texte_vider_cache' => 'Dévid lo kas',
	'titre_admin_tech' => 'Lantrotyin tèknik',
	'titre_cadre_afficher_article' => 'Afis bann zartik',
	'titre_cadre_afficher_traductions' => 'Afis léta bann tradiksyon pou lalang-la.',
	'titre_cadre_ajouter_auteur' => 'AZOUT INN LOTÈR :',
	'titre_cadre_interieur_rubrique' => 'Dann rubrik',
	'titre_cadre_numero_auteur' => 'LOTÈR NIMÉRO',
	'titre_cadre_signature_obligatoire' => '<b>Sinyatir</b> [Obligatwar]<br />',
	'titre_config_fonctions' => 'Lakonfigirasyon lo sitwèb',
	'titre_configuration' => 'Lakonfigirasyon lo sit',
	'titre_connexion_ldap' => 'Bann lopsyon : <b>Out lakostaz LDAP</b>',
	'titre_groupe_mots' => 'GROUP BANN MO :',
	'titre_langue_article' => 'LANG LARTIK-LA', # MODIF
	'titre_langue_rubrique' => 'LANG LARUBRIK-LA', # MODIF
	'titre_langue_trad_article' => 'LANG EK TRADIKSYON LARTIK',
	'titre_les_articles' => 'BANN ZARTIK',
	'titre_naviguer_dans_le_site' => 'Bat-karé sir lo sit...',
	'titre_nouvelle_rubrique' => 'Nouvèl rubrik',
	'titre_numero_rubrique' => 'RUBRIK NIMÉRO :',
	'titre_page_articles_edit' => 'Sanz : @titre@',
	'titre_page_articles_page' => 'Bann zartik',
	'titre_page_articles_tous' => 'Lo sit antyé',
	'titre_page_calendrier' => 'Kalandryé @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Lakonfigirasyon lo sit',
	'titre_page_delete_all' => 'Dégrénaz antyé. Lé pa posib artourné komand-la',
	'titre_page_recherche' => 'Bann rézilta pou lo rodaz @recherche@',
	'titre_page_statistiques_referers' => 'Bann sifklé (bann gatir i rant dann sit)',
	'titre_page_upgrade' => 'Dernyé sanzman SPIP (armizanivo)',
	'titre_publication_articles_post_dates' => 'Piblikasyion pou bann zartik daté-déryèr',
	'titre_reparation' => 'Aranzman',
	'titre_suivi_petition' => 'Pou swiv bann filsinyatir',
	'trad_article_traduction' => 'Tout bann versyon lartik-la :',
	'trad_delier' => 'Arèt gatiré lartik-la èk son bann tradiksyon', # MODIF
	'trad_lier' => 'Lartik-la lé inn tradiksyon lartik niméro :',
	'trad_new' => 'Ekri inn nouvèl tradiksyon lartik-la', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Larlik : lansanm karaktèr @charset@ li lé pa siporté.',

	// V
	'version' => 'Vesyon :',
];
